@@ -1,9 +1,12 @@
 pub extern crate geo_types;
 
 pub mod features;
+pub mod geojson_parser;
 pub mod nominatim;
 pub mod openstreetmap;
 pub mod operations;
 pub mod osmtogeojson;
+pub mod osm_parser;
+pub mod pbf_parser;
 pub mod viewer;
-pub mod interface;
+pub mod interface;
\ No newline at end of file
