@@ -9,10 +9,13 @@ use structopt::StructOpt;
 #[cfg(debug_assertions)] use log4rs;
 
 pub mod features;
+pub mod geojson_parser;
 pub mod nominatim;
 pub mod openstreetmap;
 pub mod operations;
 pub mod osmtogeojson;
+pub mod osm_parser;
+pub mod pbf_parser;
 pub mod viewer;
 pub mod interface;
 
